@@ -80,10 +80,11 @@ def get_det_location(
     out_file_name = f'{hash_data}.jpg'
     filepath = os.path.join(full_path + '/' + out_file_name)
     cv2.imwrite(filepath, im)  # 保存在本地
-    server = static_src_temp_server(server_name='det_server', full_path=full_path, port=server_port)
-    if not server.get('port_msg'):
-        filepath = '/'.join([server.get('httpserver'), out_file_name])
-    filepath = '/'.join([server.get('httpserver'), out_file_name])
+    if server_port:
+        server = static_src_temp_server(server_name='det_server', full_path=full_path, port=server_port)
+        if not server.get('port_msg'):
+            filepath = '/'.join([server.get('httpserver'), out_file_name])
+        # filepath = '/'.join([server.get('httpserver'), out_file_name])
 
     result = dict({'result': locals().get('result'), 'target_img_psth': locals().get('filepath')}, **msg)
     return result
