@@ -97,7 +97,7 @@ def static_src_temp_server(server_name: str, full_path: str = None, port: int =
         os.popen(f'''cd {server_path} && {filename}''').read().split('\n')
     # 系统类型为linux操作系统做以下操作
     if sys_type == 'posix':
-        port_status = os.popen(f'netstat -ano|grep "{port}"').read().split('\n')
+        port_status = os.popen(f'netstat -an|grep "{port}"').read().split('\n')
         if port_status[0]:
             msg['port_msg'] = '抱歉端口已经被占用'
             # 慎用
